@@ -4,7 +4,7 @@ use parent 'Set::Object';
 use strict;
 use warnings;
 
-our $VERSION = '1.08';
+our $VERSION = '2.01';
 
 # -----------------------------------------------
 
@@ -37,22 +37,6 @@ sub advance
 
 # -----------------------------------------------
 
-sub clone
-{
-	my($self) = @_;
-	my($set)  = (ref $self) -> new;
-
-	for my $automaton ($self -> members)
-	{
-		$set -> insert($automaton -> clone);
-	}
-
-	return $set;
-
-} # End of clone
-
-# -----------------------------------------------
-
 sub final
 {
 	my($self) = @_;
@@ -133,51 +117,53 @@ sub step
 
 =head1 NAME
 
-L<Set::FA> - A Set of Discrete Finite Automata
+Set::FA - A Set of Discrete Finite Automata
 
 =head1 Synopsis
 
+This is scripts/synopsis.1.pl:
+
 	#!/usr/bin/perl
-	
+
 	use strict;
 	use warnings;
-	
+
 	use Set::FA;
 	use Set::FA::Element;
-	
+
 	# --------------------------
-	
+
 	my(@a) = map
 	{
 		Set::FA::Element -> new
 		(
-		 accepting   => ['ping'],
-		 id          => "a.$_",
-		 start       => 'ping',
-		 transitions =>
-		 [
-		  ['ping', 'a', 'pong'],
-		  ['ping', '.', 'ping'],
-		  ['pong', 'b', 'ping'],
-		  ['pong', '.', 'pong'],
-		 ],
+			accepting   => ['ping'],
+			id          => "a.$_",
+			start       => 'ping',
+			transitions =>
+			[
+				['ping', 'a', 'pong'],
+				['ping', '.', 'ping'],
+				['pong', 'b', 'ping'],
+				['pong', '.', 'pong'],
+			],
 		)
 	} (0 .. 2);
-	
+
 	my(@b) = map
 	{
 		Set::FA::Element -> new
 		(
-		 accepting   => ['pong'],
-		 id          => "b.$_",
-		 start       => 'ping',
-		 transitions =>
-		 [
-		  ['ping', 'a', 'pong'],
-		  ['ping', '.', 'ping'],
-		  ['pong', 'b', 'ping'],
-		  ['pong', '.', 'pong'],
-		 ],
+			accepting   => ['pong'],
+			id          => "b.$_",
+			start       => 'ping',
+			transitions =>
+			[
+				['ping', 'a', 'pong'],
+				['ping', '.', 'ping'],
+				['pong', 'b', 'ping'],
+				['pong', '.', 'pong'],
+			],
 		)
 	} (0 .. 4);
 
@@ -186,9 +172,9 @@ L<Set::FA> - A Set of Discrete Finite Automata
 	my($sub_b) = $set -> final;
 
 	print 'Size of $sub_a: ', $sub_a -> size, ' (expect 3). ',
-	'Size of @a: ', scalar @a, ' (expect 3). ',
-	'Size of $sub_b: ', $sub_b -> size, ' (expect 5). ',
-	'Size of @b: ', scalar @b, ' (expect 5). ', "\n",
+		'Size of @a: ', scalar @a, ' (expect 3). ',
+		'Size of $sub_b: ', $sub_b -> size, ' (expect 5). ',
+		'Size of @b: ', scalar @b, ' (expect 5). ', "\n",
 
 =head1 Description
 
@@ -231,11 +217,11 @@ documentation.
 
 =head2 Using new()
 
-C<new()> is called as C<< my($set) = Set::FA -> new(@list_of_dfas) >>.
+L</new([@list_of_dfas])> is called as C<< my($set) = Set::FA -> new(@list_of_dfas) >>.
 
 It returns a new object of type C<Set::FA>.
 
-You may supply a list of L<Set::FA::Element> objects to new.
+You may supply a list of L<Set::FA::Element> objects to L</new([@list_of_dfas])>.
 
 If the list is empty, you will need to call $set -> insert(@list_of_dfas) to do anything meaningful
 with $set.
@@ -252,7 +238,7 @@ synopsis.
 Calls L<Set::FA::Element/accept($input)> on all members of the set. This in turn calls
 L<Set::FA::Element/advance($input)> on each member.
 
-Note: This does I<not> mean it calls advance() on the set object.
+Note: This does I<not> mean it calls C<advance()> on the set object.
 
 Returns a L<Set::FA> object containing just the members of the original set which have ended up
 in their respective accepting states.
@@ -263,11 +249,6 @@ Calls L<Set::FA::Element/advance($input)> on all members of the set.
 
 Returns nothing.
 
-=head2 clone()
-
-Returns a clone of the set. All references (except for code references) in the
-new set point to newly created objects.
-
 =head2 final()
 
 Calls L<Set::FA::Element/final()> on all members of the set.
@@ -285,6 +266,12 @@ match the $id parameter.
 Returns a L<Set::FA> object containing just the members of the original set who current
 state matches the $state parameter.
 
+=head2 new([@list_of_dfas])
+
+Here, the [] indicate an optional parameter.
+
+The constructor. See L</Constructor and Initialization>.
+
 =head2 reset()
 
 Calls L<Set::FA::Element/reset()> on all members of the set.
@@ -297,9 +284,13 @@ Calls L<Set::FA::Element/step($input)> on all members of the set.
 
 Returns nothing.
 
+=head1 FAQ
+
+See L<Set::FA::Element/FAQ>.
+
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
@@ -310,14 +301,15 @@ Version numbers < 1.00 represent development versions. From 1.00 up, they are pr
 The code was rewritten to perform exactly as did earlier versions (pre-1.00) of L<Set::FA> and
 L<Set::FA::Element>, and hence is essentially the same, line for line.
 
-I've reformatted it, and changed the OO nature and the logging, obviously, but Mark Rogaski, the author of
-L<Set::FA> gets the credit for the code.
+I've reformatted it, and changed the OO nature and the logging, obviously, but Mark Rogaski, the
+author of L<Set::FA> gets the credit for the code.
 
 I've rewritten the documentation from scratch.
 
 =head1 See Also
 
-Before adopting L<Set::FA> (for L<Graph::Easy::Marpa>'s lexer), other DFA modules I looked at were:
+Before adopting L<Set::FA> (for L<Graph::Easy::Marpa>'s lexer), here are some other DFA modules I
+found on L<https://metacpan.org>:
 
 =over 4
 
@@ -334,14 +326,28 @@ and can output in a range of languages. See L<http://smc.sourceforge.net/>.
 SMC looks sophisticated, but it's a rather indirect way of doing things when Perl modules such
 as L<Set::FA::Element> are already available.
 
+=item o L<Dict::FSA>
+
+This module is a perl wrapper around C<fsa>, a set of tools based on finite state automata.
+
+See L<http://www.eti.pg.gda.pl/~jandac/fsa.html>.
+
 =item o L<DMA::FSM>
 
 Uses a very old-fashioned style of writing Perl.
 
-=item o FLAT::DSA. See L<FLAT>
+=item o FLAT::DFA. See L<FLAT>
 
 A toolkit for manipulating DFAs.
 
+=item o L<FSA::Engine>
+
+A Moose Role to convert an object into a Finite State Machine.
+
+=item o L<FSA::Rules>
+
+Build simple rules-based state machines in Perl.
+
 =item o L<IDS::Algorithm::DFA>
 
 Uses an old-fashioned style of writing Perl.
@@ -369,17 +375,21 @@ You build up a transition network diagram, labouriously, with 1 line of code at
 
 See also L<this Wikipedia article|http://en.wikipedia.org/wiki/Deterministic_finite-state_machine>.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Set-FA>
+
 =head1 Support
 
 Email the author, or log a bug on RT:
 
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set::FA>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set::FA>
 
 =head1 Author
 
 L<Set::FA> was written by Mark Rogaski and Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2011.
 
-Home page: L<http://savage.net.au/index.html>.
+My homepage: L<http://savage.net.au/index.html>
 
 =head1 Copyright
 
@@ -387,7 +397,7 @@ Australian copyright (c) 2011, Ron Savage.
 
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
-	The Artistic License, a copy of which is available at:
+	The Perl License, a copy of which is available at:
 	http://www.opensource.org/licenses/index.html
 
 =cut
