@@ -3,22 +3,136 @@ package Set::FA::Element;
 use strict;
 use warnings;
 
-use Hash::FieldHash ':all';
+use Log::Handler;
 
-fieldhash my %accepting   => 'accepting';
-fieldhash my %actions     => 'actions';
-fieldhash my %current     => 'current';
-fieldhash my %data        => 'data';
-fieldhash my %die_on_loop => 'die_on_loop';
-fieldhash my %id          => 'id';
-fieldhash my %logger      => 'logger';
-fieldhash my %match       => 'match';
-fieldhash my %start       => 'start';
-fieldhash my %stt         => 'stt';
-fieldhash my %transitions => 'transitions';
-fieldhash my %verbose     => 'verbose';
+use Moo;
 
-our $VERSION = '1.08';
+use Types::Standard qw/Any ArrayRef Bool HashRef Str/;
+
+has accepting =>
+(
+	default		=> sub{return []},
+	is			=> 'rw',
+	isa			=> ArrayRef,
+	required	=> 0,
+);
+
+has actions =>
+(
+	default		=> sub{return {} },
+	is			=> 'rw',
+	isa			=> HashRef,
+	required	=> 0,
+);
+
+has current => # Internal.
+(
+	default		=> sub{return ''},
+	is			=> 'rw',
+	isa			=> Str,
+	required	=> 0,
+);
+
+has die_on_loop =>
+(
+	default		=> sub{return 0},
+	is			=> 'rw',
+	isa			=> Bool,
+	required	=> 0,
+);
+
+has id =>
+(
+	default		=> sub{return ''},
+	is			=> 'rw',
+	isa			=> Str,
+	required	=> 0,
+);
+
+has logger =>
+(
+	default		=> sub{return undef},
+	is			=> 'rw',
+	isa			=> Any,
+	required	=> 0,
+);
+
+has match => # Internal.
+(
+	default		=> sub{return ''},
+	is			=> 'rw',
+	isa			=> Str,
+	required	=> 0,
+);
+
+has maxlevel =>
+(
+	default		=> sub{return 'notice'},
+	is			=> 'rw',
+	isa			=> Str,
+	required	=> 0,
+);
+
+has minlevel =>
+(
+	default		=> sub{return 'error'},
+	is			=> 'rw',
+	isa			=> Str,
+	required	=> 0,
+);
+
+has start =>
+(
+	default		=> sub{return ''},
+	is			=> 'rw',
+	isa			=> Str,
+	required	=> 0,
+);
+
+has stt => # Internal.
+(
+	default		=> sub{return {} },
+	is			=> 'rw',
+	isa			=> HashRef,
+	required	=> 0,
+);
+
+has transitions =>
+(
+	default		=> sub{return []},
+	is			=> 'rw',
+	isa			=> ArrayRef,
+	required	=> 0,
+);
+
+our $VERSION = '2.01';
+
+# -----------------------------------------------
+
+sub BUILD
+{
+	my($self) = @_;
+
+	if (! defined $self -> logger)
+	{
+		$self -> logger(Log::Handler -> new);
+		$self -> logger -> add
+		(
+			screen =>
+			{
+				maxlevel		=> $self -> maxlevel,
+				message_layout	=> '%m',
+				minlevel		=> $self -> minlevel,
+				utf8			=> 1,
+			}
+		);
+	}
+
+	$self -> validate_params;
+	$self -> build_stt;
+	$self -> current($self -> start);
+
+} # End of BUILD.
 
 # -----------------------------------------------
 
@@ -64,8 +178,8 @@ sub advance
 
 sub build_stt
 {
-	my($self)   = @_;
-	my(%action) = %{$self -> actions};
+	my($self)	= @_;
+	my(%action)	= %{$self -> actions};
 
 	# Reformat the actions.
 
@@ -86,8 +200,8 @@ sub build_stt
 
 	# Reformat the acceptings.
 
-	my(@accepting) = @{$self -> accepting};
-	my($row)       = 0;
+	my(@accepting)	= @{$self -> accepting};
+	my($row)		= 0;
 
 	my(%accept);
 	my($entry_fn, $entry_name, $exit_fn, $exit_name);
@@ -130,12 +244,12 @@ sub build_stt
 		{
 			# Warning: $regexp must be declared in this scope.
 
-			my($regexp) = qr/($rule)/;
-			$rule_sub   = sub
+			my($regexp)	= qr/^($rule)(.*)/;
+			$rule_sub	= sub
 			{
 				my($class, $input) = @_;
 
-				return $input =~ /^$regexp(.*)/ ? ($1, $2) : (undef, undef);
+				return $input =~ $regexp ? ($1, $2) : (undef, undef);
 			};
 		}
 
@@ -155,8 +269,8 @@ sub build_stt
 
 				if (ref $entry_fn eq 'ARRAY')
 				{
-					$entry_name = $$entry_fn[1];
-					$entry_fn   = $$entry_fn[0];
+					$entry_name	= $$entry_fn[1];
+					$entry_fn	= $$entry_fn[0];
 				}
 				else
 				{
@@ -170,8 +284,8 @@ sub build_stt
 
 				if (ref $exit_fn eq 'ARRAY')
 				{
-					$exit_name = $$exit_fn[1];
-					$exit_fn   = $$exit_fn[0];
+					$exit_name	= $$exit_fn[1];
+					$exit_fn	= $$exit_fn[0];
 				}
 				else
 				{
@@ -181,13 +295,13 @@ sub build_stt
 
 			$stt{$state} =
 			{
-				accept     => $accept{$state} || 0,
-				entry_fn   => $entry_fn,
-				entry_name => $entry_name,
-				exit_fn    => $exit_fn,
-				exit_name  => $exit_name,
-				rule   => [ [$rule_sub, $next, $rule] ],
-				start  => 0,
+				accept		=> $accept{$state} || 0,
+				entry_fn	=> $entry_fn,
+				entry_name	=> $entry_name,
+				exit_fn		=> $exit_fn,
+				exit_name	=> $exit_name,
+				rule		=> [ [$rule_sub, $next, $rule] ],
+				start		=> 0,
 			};
 		}
 
@@ -219,51 +333,6 @@ sub build_stt
 
 # -----------------------------------------------
 
-sub clone
-{
-	my($self) = @_;
-
-	$self -> log(debug => 'Entered clone()');
-
-	my($clone) = _clone($self);
-
-	return bless $clone, ref $self;
-
-} # End of clone.
-
-# -----------------------------------------------
-
-sub _clone
-{
-	my($data) = @_;
-
-	use attributes 'reftype';
-
-	return $data if (! ref $data);
-
-	if (reftype($data) eq 'ARRAY')
-	{
-		return [map{_clone($_)} @$data];
-	}
-	elsif (reftype($data) eq 'HASH')
-	{
-		return {map{$_ => _clone($_)} keys %$data};
-	}
-	elsif (reftype($data) eq 'SCALAR')
-	{
-		my($thing) = _clone($data);
-
-		return \$thing;
-	}
-	else
-	{
-		return $data;
-	}
-
-} # End of _clone.
-
-# -----------------------------------------------
-
 sub final
 {
 	my($self, $state) = @_;
@@ -276,72 +345,18 @@ sub final
 
 } # End of final.
 
-# -----------------------------------------------
-
-sub _init
-{
-	my($self, $arg)    = @_;
-	$$arg{accepting}   ||= []; # Caller can set.
-	$$arg{actions}     ||= {}; # Caller can set.
-	$$arg{current}     = '';
-	$$arg{data}        ||= ''; # Caller can set.
-	$$arg{die_on_loop} ||= 0;  # Caller can set.
-	$$arg{id}          ||= 0;  # Caller can set.
-	$$arg{logger}      ||= ''; # Caller can set.
-	$$arg{match}       = '';
-	$$arg{start}       ||= ''; # Caller must set.
-	$$arg{stt}         = {};
-	$$arg{transitions} ||= []; # Caller must set.
-	$$arg{verbose}     ||= 0;  # Caller can set.
-	$self              = from_hash($self, $arg);
-
-	$self -> validate_params;
-	$self -> build_stt;
-	$self -> current($self -> start);
-
-	return $self;
-
-} # End of _init.
-
-# -----------------------------------------------
+# --------------------------------------------------
 
 sub log
 {
-	my($self, $level, $message) = @_;
-	$level   ||= 'debug';
-	$message ||= '';
+	my($self, $level, $s) = @_;
 
-	if ($level eq 'error')
-	{
-		die $message;
-	}
-
-	if ($self -> logger)
-	{
-		$self -> logger -> $level($message);
-	}
-	elsif ($self -> verbose)
-	{
-		print "$level: $message\n";
-	}
-
-	return $self;
+	$self -> logger -> log($level => $s) if ($self -> logger);
 
 } # End of log.
 
 # -----------------------------------------------
 
-sub new
-{
-	my($class, %arg) = @_;
-	my($self)        = bless {}, $class;
-
-	return $self -> _init(\%arg);
-
-}	# End of new.
-
-# -----------------------------------------------
-
 sub report
 {
 	my($self) = @_;
@@ -396,8 +411,9 @@ sub reset
 	my($self) = @_;
 
 	$self -> log(debug => 'Entered reset()');
+	$self -> current($self -> start);
 
-	return $self -> current($self -> start) -> current;
+	return $self -> current;
 
 } # End of reset.
 
@@ -421,8 +437,8 @@ sub step
 
 	$self -> log(debug => 'Entered step()');
 
-	my($current) = $self -> current;
-	my($stt)     = $self -> stt;
+	my($current)	= $self -> current;
+	my($stt)		= $self -> stt;
 
 	my($match);
 	my($next);
@@ -431,9 +447,9 @@ sub step
 
 	for my $item (@{$$stt{$current}{rule} })
 	{
-		($rule_sub, $next, $rule) = @$item;
-		($match, $output)         = $rule_sub -> ($self, $input);
- 
+		($rule_sub, $next, $rule)	= @$item;
+		($match, $output)			= $rule_sub -> ($self, $input);
+
 		if (defined $match)
 		{
 			$self -> match($match);
@@ -514,30 +530,55 @@ L<Set::FA::Element> - Discrete Finite Automaton
 
 =head1 Synopsis
 
-	#!/usr/bin/perl
-	
+This is scripts/synopsis.2.pl (a test-free version of t/report.t):
+
+	#!/usr/bin/env perl
+
 	use strict;
 	use warnings;
-	
+
 	use Set::FA::Element;
-	
+
 	# --------------------------
-	
+
 	my($dfa) = Set::FA::Element -> new
 	(
-	 accepting   => ['baz'],
-	 start       => 'foo',
-	 transitions =>
-	 [
-	  ['foo', 'b', 'bar'],
-	  ['foo', '.', 'foo'],
-	  ['bar', 'a', 'foo'],
-	  ['bar', 'b', 'bar'],
-	  ['bar', 'c', 'baz'],
-	  ['baz', '.', 'baz'],
-	 ],
+		accepting	=> ['baz'],
+		maxlevel	=> 'debug',
+		start		=> 'foo',
+		transitions	=>
+		[
+			['foo', 'b', 'bar'],
+			['foo', '.', 'foo'],
+			['bar', 'a', 'foo'],
+			['bar', 'b', 'bar'],
+			['bar', 'c', 'baz'],
+			['baz', '.', 'baz'],
+		],
 	);
-	
+
+	print "Got: \n";
+	$dfa -> report;
+
+	print "Expected: \n", <<EOS;
+	Entered report()
+	State Transition Table
+	State: bar
+	Rule => Next state
+	/a/ => foo
+	/b/ => bar
+	/c/ => baz
+	State: baz. This is an accepting state
+	Rule => Next state
+	/./ => baz
+	State: foo. This is the start state
+	Rule => Next state
+	/b/ => bar
+	/./ => foo
+	EOS
+
+	Or make use of:
+
 	my($boolean)  = $dfa -> accept($input);
 	my($current)  = $dfa -> advance($input);
 	my($state)    = $dfa -> current;
@@ -584,8 +625,8 @@ or:
 
 =head2 Parentage
 
-You can easily subclass L<Set::FA::Element> by having your subclass use exactly the same logic as in the code,
-- see new(), and _init() - after declaring your getters and setters using the Hash::FieldHash syntax.
+You can easily subclass L<Set::FA::Element> by having your subclass use exactly the same logic as
+in the code, after declaring your Moo-based getters and setters.
 
 =head2 Using new()
 
@@ -596,8 +637,9 @@ It returns a new object of type C<Set::FA::Element>.
 Key-value pairs accepted in the parameter list are as follows. Also, each is also a method,
 so you can retrieve the value and update it at any time.
 
-Naturally, after the internal state transition table has been constructed (during the call to new() ),
-updating some of these fields will be ignored. Methods which I<are> effective later are documented.
+Naturally, after the internal state transition table has been constructed (during the call to
+C<new()>), updates to some of these fields will be ignored. Methods which I<are> effective later
+are documented.
 
 =over 4
 
@@ -618,7 +660,7 @@ This means you can have only 1 entry function and 1 exit function per state.
 For a module which gives you the power to have a different entry and exit function
 for each different regexp which matches the input, see the (as yet unwritten) Set::FA::Manifold.
 
-Format:
+For a given state name key, the value is a hashref with 1 or 2 of these keys:
 
 =over 4
 
@@ -642,22 +684,14 @@ The point of the [\&fn, 'fn'] version is when you call report(), and the 'fn' st
 
 =back
 
-Each of these functions is called (in method step_state() ) with the DFA object as the only parameter.
+Each of these functions is called (in method step_state() ) with the DFA object as the only
+parameter. You use that object to call the methods listed in these docs. See L</Synopsis> for
+a list.
 
 This key is optional.
 
 The default is {}.
 
-=item o data => $string
-
-A place to store anything you want, per DFA.
-
-Retrieve and update the value with the data() method.
-
-This key is optional.
-
-The default is ''.
-
 =item o die_on_loop => $boolean
 
 Provides a way for the code to keep running, or die, when the advance() method determines that
@@ -683,19 +717,37 @@ This key is optional.
 
 The default is ''.
 
-=item o logger => $logger_object
+=item o logger => $aLoggerObject
 
-Provides a logger object whose $level($message) method is called at certain times.
+Specify a logger compatible with L<Log::Handler>, for the lexer and parser to use.
 
-See L</Why such a different approach to logging?> in the L</FAQ> for details.
+Default: A logger of type L<Log::Handler> which writes to the screen.
 
-Retrieve and update the value with the logger() method.
+To disable logging, just set 'logger' to the empty string (not undef).
 
-This key is optional.
+=item o maxlevel => $logOption1
 
-The default is ''.
+This option affects L<Log::Handler>.
 
-See also the verbose option, which can interact with the logger option.
+See the L<Log::Handler::Levels> docs.
+
+By default nothing is printed.
+
+Typical values are: 'error', 'notice', 'info' and 'debug'.
+
+The default produces no output.
+
+Default: 'notice'.
+
+=item o minlevel => $logOption2
+
+This option affects L<Log::Handler>.
+
+See the L<Log::Handler::Levels> docs.
+
+Default: 'error'.
+
+No lower levels are used.
 
 =item o start => $name_of_start_state
 
@@ -709,7 +761,8 @@ There is no default.
 
 =item o transitions => []
 
-Provides a complex arrayref of state names and regexps which control the transitions between states.
+Provides a complex arrayref of state names and regexps which control the transitions between
+states.
 
 Each element of this arrayref is itself an arrayref of 3 elements:
 
@@ -751,55 +804,10 @@ This key is mandatory.
 
 There is no default.
 
-=item o verbose => $boolean
-
-Provides a way to control the amount of output when a logger is not specified.
-
-Setting verbose to 0 means print nothing.
-
-Setting verbose to 1 means print the log level and the message to STDOUT, when a logger is not specified.
-
-This key is optional.
-
-Retrieve and update the value with the verbose() method.
-
-The default is 0.
-
-See also the logger option, which can interact with the verbose option.
-
 =back
 
 =head1 Methods
 
-Note: Methods generated by Hash::FieldHash are designed to operate like this:
-
-=over 4
-
-=item o When called without a parameter...
-
-They return the value they are managing. Hence:
-
-	my($current_state) = $dfa -> current.
-
-=item o When called with a parameter...
-
-They return the object, to allow method chaining. Hence:
-
-	$dfa -> current($new_state);
-	my($current_state) = $dfa -> current;
-
-Don't do this:
-
-	my($current_state_no_no) = $dfa -> current($new_state);
-
-You could do this:
-
-	my($current_state) = $dfa -> current($new_state) -> current;
-
-=back
-
-All such methods below warn of this.
-
 =head2 accept($input)
 
 Calls L</advance($input)>.
@@ -808,17 +816,30 @@ Returns 1 if the 'current' state - after processing the input - is an accepting
 
 Returns 0 otherwise.
 
+=head2 accepting($arrayref_of_states)
+
+See L</Using new()> for details.
+
+C<accepting> is a parameter to L</new([%args])>.
+
+=head2 actions($arrayref_of_states)
+
+See L</Using new()> for details.
+
+C<actions> is a parameter to L</new([%args])>.
+
 =head2 advance($input)
 
 Calls L</step($input)> repeatedly on the unconsumed portion of the input.
 
 Returns the 'current' state at the end of that process.
 
-Since L</step($input)> calls L</match($consumed_input)> upon every match, and L</step_state($next)> too, you
-necessarily lose access to the individual portions of the input matched by successive
+Since L</step($input)> calls L</match($consumed_input)> upon every match, and L</step_state($next)>
+too, you necessarily lose access to the individual portions of the input matched by successive
 runs of the coderef per transition table entry.
 
-At the end of this process, then, L</match($consumed_input)> can only return the last portion matched.
+At the end of this process, then, L</match($consumed_input)> can only return the last portion
+matched.
 
 See L</step($input)> for advancing the DFA by a single transition.
 
@@ -828,9 +849,7 @@ Logging note:
 
 =item o When die_on_loop is 0
 
-Then, advance() calls $your_logger -> warning($message) when input is not consumed.
-
-If there is no logger, calls print "warning: $message\n". But, when verbose is 0, prints nothing.
+Then, advance() calls $your_logger -> log(warning => $message) when input is not consumed.
 
 =item o When die_on_loop is 1
 
@@ -855,13 +874,9 @@ Use these parameters to new() to construct a state transition table:
 =back
 
 Note: The private method _init() calls validate_params() I<before> calling build_stt(), so if
-you call accepting($new_accepting), actions($new_actions), start($new_start) and transtions($new_transitions),
-for some reason, and then call build_stt(), you will miss out on the benefit of calling validate_params().
-So don't do that!
-
-=head2 clone()
-
-Returns a deep copy of the L<Set::FA::Element> object.
+you call accepting($new_accepting), actions($new_actions), start($new_start) and
+transtions($new_transitions), for some reason, and then call build_stt(), you will miss out on the
+benefit of calling validate_params(). So don't do that!
 
 =head2 current([$state])
 
@@ -877,27 +892,13 @@ Returns the 'current' state of the DFA.
 
 Sets the 'current' state of the DFA.
 
-Returns the object, for method chaining.
-
 =back
 
-=head2 data([$string])
+=head2 die_on_loop([$Boolean])
 
-Here, the [] indicate an optional parameter.
+See L</Using new()> for details. See also L</advance($input)> for a discussion of C<die_on_loop>.
 
-=over 4
-
-=item o When $string is not provided
-
-Returns the data associated with the object.
-
-=item o When $data is provided
-
-Sets the data associated with the object.
-
-Returns the object, for method chaining.
-
-=back
+C<die_on_loop> is a parameter to L</new([%args])>.
 
 =head2 final([$state])
 
@@ -923,70 +924,57 @@ Returns 0 otherwise.
 
 Here, the [] indicate an optional parameter.
 
-=over 4
+See L</Using new()> for details.
 
-=item o When $id is not provided
+C<id> is a parameter to L</new([%args])>.
 
-Returns the id of the object.
+=head2 log($level, $message)
 
-=item o When $id is provided
+Calls log($level, $message) on the logger object if that object is defined.
 
-Sets the id of the object.
+To stop this, set the logger to '' in the call to L</new([%args])>.
 
-Returns the object, for method chaining.
+=head2 logger($arrayref_of_states)
 
-=back
+See L</Using new()> for details.
 
-=head2 log([$level, $message])
+C<logger> is a parameter to L</new([%args])>.
 
-Here, the [] indicate an optional parameters.
-
-If you call it as $dfa -> log(), $level defaults to 'debug' and $message defaults to ''.
-
-Firstly, the error level is checked:
-
-	if ($level eq 'error')
-	{
-	    die $message;
-	}
-
-If not an error, log() then executes this line:
-
-	if ($self -> logger)                     # If there is a logger...
-	{
-	    $self -> logger -> $level($message); # Call it.
-	}
-	elsif ($self -> verbose)                 # Otherwise (no logger) and we're in verbose mode...
-	{
-	    print "$level: $message\n";          # Print.
-	}
-	                                         # Otherwise (silent) do nothing.
-
-Returns the object, for method chaining.
-
-=head2 logger([$logger_object])
+=head2 maxlevel([$string])
 
 Here, the [] indicate an optional parameter.
 
-=over 4
+See L</Using new()> for details.
 
-=item o When $logger_object is not provided
+Get or set the value used by the logger object.
 
-Sets the internal logger object to ''.
+This option is only used if an object of type L<Log::Handler> is ceated, and such an object is
+created by default. To stop this, set the logger to '' in the call to L</new([%args])>.
 
-=item o When $logger_object is provided
+See L<Log::Handler::Levels>.
 
-Sets the internal logger object to $logger_object.
+Typical values are: 'notice', 'info' and 'debug'. The default, 'notice', produces no output.
 
-This allows you to change the log levels accepted and suppressed by the logger object,
-during the run of the DFA.
+C<maxlevel> is a parameter to L</new([%args])>.
 
-You are strongly advised to read L</Why such a different approach to logging?>, as well as the notes
-on the logging and verbose options to new().
+=head2 minlevel([$string])
 
-=back
+Here, the [] indicate an optional parameter.
 
-Returns the internal logger object, or ''.
+See L</Using new()> for details.
+
+Get or set the value used by the logger object.
+
+This option is only used if an object of type L<Log::Handler> is ceated, and such an object is
+created by default. To stop this, set the logger to '' in the call to L</new([%args])>.
+
+See L<Log::Handler::Levels>.
+
+C<minlevel> is a parameter to L</new([%args])>.
+
+=head2 new([%args])
+
+The constructor. See L</Constructor and Initialization>.
 
 =head2 match([$consumed_input])
 
@@ -1002,8 +990,6 @@ Returns the portion of the input matched by the most recent step of the DFA.
 
 Sets the internal string which will be returned by calling match().
 
-Returns the object, for method chaining.
-
 =back
 
 =head2 report()
@@ -1022,19 +1008,9 @@ Does not reset the id or anything else associated with the object.
 
 Here, the [] indicate an optional parameter.
 
-=over 4
+See L</Using new()> for details.
 
-=item o When $start is not provided
-
-Returns the start state of the object.
-
-=item o When $start is provided
-
-Sets the start state of the object.
-
-Returns the object, for method chaining.
-
-=back
+C<start> is a parameter to L</new([%args])>.
 
 =head2 state([$state])
 
@@ -1061,7 +1037,8 @@ Advances the DFA by a single transition, if possible.
 The code checks each entry in the transitions arrayref supplied to new(), in order,
 looking for entries whose 1st element ($state) matches the 'current' state.
 
-Upon the first match found (if any), the code runs the coderef in the 2nd element ($rule_sub) of that entry.
+Upon the first match found (if any), the code runs the coderef in the 2nd element ($rule_sub) of
+that entry.
 
 If there is a match:
 
@@ -1096,6 +1073,12 @@ If they match, returns 0 immediately.
 
 =back
 
+=head2 transitions($arrayref_of_states)
+
+See L</Using new()> for details.
+
+C<transitions> is a parameter to L</new([%args])>.
+
 =head2 validate()
 
 Perform validation checks on these parameters to new():
@@ -1112,24 +1095,63 @@ Perform validation checks on these parameters to new():
 
 =head1 FAQ
 
-=head2 What's changed in V 1.00 of L<Set::FA::Element>?
+=head2 How do I protect the code from dying?
+
+Use L<Capture::Tiny>. See t/report.t for a simple example.
+
+=head2 What's changed in V 2.00 of C<Set::FA::Element>?
 
 =over 4
 
-=item o Use Hash::FieldHash for getters and setters
+=item o Put the distro on github
+
+See L</Repository> below.
+
+=item o Switch to Moo
+
+=item o This means method chaining is no longer supported
+
+=item o Explicitly default the logger to an instance of L<Log::Handler>
+
+=item o Add maxlevel() and minlevel() for controlling the logger
+
+=item o Rewrite log so messages do not have the prefix of "$level: "
+
+=item o Make the synopses in both modules into stand-alone scripts
+
+See scripts/synopsis.*.pl.
+
+=item o Add 'use strict' and 'use warnings' to t/*.t
+
+=item o Move t/pod.t to xt/author/
+
+=item o Switch from Test::More to Test::Stream
+
+=item o Remove verbose()
+
+=back
+
+=head2 What's changed in V 1.00 of C<Set::FA::Element>?
+
+Note: I have switched to Moo and Log::Handler.
+
+=over 4
+
+=item o Use Moo for getters and setters
 
 Originally, L<Set::FA::Element> used direct hash access to implement the logic.
 I did not want to do that. At the same time, I did not want users to incur the overhead
 of L<Moose>.
 
-So, I've adopted my standard policy of using L<Hash::FieldHash> in stand-alone modules and L<Moose> in apps.
+So, I've adopted my standard policy of using L<Moo>.
 
 =item o Rename the new() parameter from accept to accepting
 
-While direct hash access allowed the author of L<Set::FA::Element> to have a hash key and a method with the
-same name, accept, I can't do that now.
+While direct hash access allowed the author of L<Set::FA::Element> to have a hash key and a method
+with the same name, accept, I can't do that now.
 
-So, the parameter to new() (in L<Set::FA::Element>) is called accepting, and the method is still called accept().
+So, the parameter to new() (in L<Set::FA::Element>) is called accepting, and the method is still
+called accept().
 
 =item o Add a parameter to new(), die_on_loop
 
@@ -1155,8 +1177,6 @@ This makes it easy to change the quantity of progress reports.
 
 =item o Add a method, current() to set/get the current state
 
-=item o Add a method, data() to set/get the arbitrary data per object
-
 =item o Add a method, die_on_loop() to set/get the like-named option
 
 =item o Add a method, id() to set/get the id per object
@@ -1181,26 +1201,31 @@ This makes it easy to change the quantity of progress reports.
 
 Firstly, L<Set::FA::Element> used L<Log::Agent>. I always use L<Log::Handler> these days.
 
-By default (i.e. without a logger object), L<Set::FA::Element> prints messages to STDOUT, and dies upon errors.
+By default (i.e. without a logger object), L<Set::FA::Element> prints messages to STDOUT, and dies
+upon errors.
 
 However, by supplying a log object, you can capture these events.
 
 Not only that, you can change the behaviour of your log object at any time, by calling
 L</logger($logger_object)>.
 
-Specifically, $logger_object -> log(debug => 'Entered x()') is called at the start of each public method.
+Specifically, $logger_object -> log(debug => 'Entered x()') is called at the start of each public
+method.
 
 Setting your log level to 'debug' will cause these messages to appear.
 
-Setting your log level to anything below 'debug', e.g. 'info, 'notice', 'warning' or 'error', will suppress them.
+Setting your log level to anything below 'debug', e.g. 'info, 'notice', 'warning' or 'error', will
+suppress them.
 
 Also, L</step_state($next)> calls:
 
-	$self -> log(info => "Stepped from state '$current' to '$next' using rule /$rule/ to match '$match'");
+	$self -> log(info => "Stepped from state '$current' to '$next' using rule /$rule/ to match
+	'$match'");
 
 just before it returns.
 
-Setting your log level to anything below 'info', e.g. 'notice', 'warning' or 'error', will suppress this message.
+Setting your log level to anything below 'info', e.g. 'notice', 'warning' or 'error', will suppress
+this message.
 
 Hence, by setting the log level to 'info', you can log just 1 line per state transition, and no other
 messages, to minimize output.
@@ -1214,13 +1239,14 @@ Lastly, although this logging mechanism may seem complex, it has distinct advant
 This method uses a global variable to control the level of logging. This means the code using
 L<Set::FA::Element> can (also) use L<Log::Agent> and call logconfig(...),
 which in turn affects the behaviour of the logging calls inside those other modules.
-I assume this design is deliberate, but I certainly don't like it, because (I suspect) it means any running Perl
-program which changes the configuration affects all other running programs using L<Log::Agent>.
+I assume this design is deliberate, but I certainly don't like it, because (I suspect) it means any
+running Perl program which changes the configuration affects all other running programs using
+L<Log::Agent>.
 
 =item o Log levels
 
-You can configure your logger object, either before calling new(), or at any later time, by changing your logger object,
-and then calling L</logger($logger_object)>.
+You can configure your logger object, either before calling new(), or at any later time, by
+changing L</minlevel([$string])> or L</maxlevel([$string])>.
 
 That allows you complete control over the logging activity.
 
@@ -1232,7 +1258,7 @@ Error messages are self-documenting, in that when you trigger them, you get to r
 
 =head1 Machine-Readable Change Log
 
-The file CHANGES was converted into Changelog.ini by L<Module::Metadata::Changes>.
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
 =head1 Version Numbers
 
@@ -1246,17 +1272,22 @@ See L<Set::FA/Credit>.
 
 See L<Set::FA/See Also>.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Set-FA>
+
 =head1 Support
 
 Email the author, or log a bug on RT:
 
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set::FA>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set::FA>
 
 =head1 Author
 
-L<Set::FA::Element> was written by Mark Rogaski and Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2011.
+L<Set::FA::Element> was written by Mark Rogaski and Ron Savage I<E<lt>ron@savage.net.auE<gt>> in
+2011.
 
-Home page: L<http://savage.net.au/index.html>.
+My homepage: L<http://savage.net.au/index.html>
 
 =head1 Copyright
 
@@ -1264,7 +1295,7 @@ Australian copyright (c) 2011, Ron Savage.
 
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
-	The Artistic License, a copy of which is available at:
+	The Perl License, a copy of which is available at:
 	http://www.opensource.org/licenses/index.html
 
 =cut
